@@ -3,5 +3,6 @@ from .json_writer import JsonWriter
 from .mongo_writer import MongoWriter
 from .mysql_writer import MySqlWriter
 from .txt_writer import TxtWriter
+from .sqlite_writer import SqliteWriter
 
-__all__ = [CsvWriter, TxtWriter, JsonWriter, MongoWriter, MySqlWriter]
+__all__ = [CsvWriter, TxtWriter, JsonWriter, MongoWriter, MySqlWriter, SqliteWriter]
